summaryrefslogtreecommitdiff
path: root/include/vcl
diff options
context:
space:
mode:
authorNoel Grandin <noel.grandin@collabora.co.uk>2023-07-19 15:19:28 +0200
committerNoel Grandin <noel.grandin@collabora.co.uk>2023-07-20 08:15:29 +0200
commit0e8b7dd7a013dffe080148baac926a698f36ad85 (patch)
tree940962b117c06943784aa94f1116bf748a2d057c /include/vcl
parent669d6ed4fa2e7a01c372a6e27dd5468ec8eb3077 (diff)
split GetWindowExtentsRelative asunder
sometimes it returns a relative position, sometimes an absolute position. Rather have two different methods with names that match what they return. Change-Id: Ie1e73c6be1c797fd59934c96866d1fef1f972b35 Reviewed-on: https://gerrit.libreoffice.org/c/core/+/154653 Tested-by: Jenkins Reviewed-by: Noel Grandin <noel.grandin@collabora.co.uk>
Diffstat (limited to 'include/vcl')
-rw-r--r--include/vcl/accessibletable.hxx3
-rw-r--r--include/vcl/accessibletableprovider.hxx3
-rw-r--r--include/vcl/toolkit/svtabbx.hxx3
-rw-r--r--include/vcl/window.hxx8
4 files changed, 10 insertions, 7 deletions
diff --git a/include/vcl/accessibletable.hxx b/include/vcl/accessibletable.hxx
index 7d6af73e8934..5eeaa528bdd9 100644
--- a/include/vcl/accessibletable.hxx
+++ b/include/vcl/accessibletable.hxx
@@ -73,7 +73,8 @@ public:
AccessibleTableControlObjType eObjType ) const= 0;
// Window
- virtual tools::Rectangle GetWindowExtentsRelative(const vcl::Window *pRelativeWindow) const = 0;
+ virtual tools::Rectangle GetWindowExtentsAbsolute() const = 0;
+ virtual tools::Rectangle GetWindowExtentsRelative(const vcl::Window& rRelativeWindow) const = 0;
virtual void GrabFocus()= 0;
virtual css::uno::Reference< css::accessibility::XAccessible > GetAccessible()= 0;
virtual vcl::Window* GetAccessibleParentWindow() const= 0;
diff --git a/include/vcl/accessibletableprovider.hxx b/include/vcl/accessibletableprovider.hxx
index 94e5d85832d1..63f8580ee801 100644
--- a/include/vcl/accessibletableprovider.hxx
+++ b/include/vcl/accessibletableprovider.hxx
@@ -113,7 +113,8 @@ public:
virtual bool GetGlyphBoundRects( const Point& rOrigin, const OUString& rStr, int nIndex, int nLen, std::vector< tools::Rectangle >& rVector ) = 0;
// Window
- virtual tools::Rectangle GetWindowExtentsRelative(const vcl::Window *pRelativeWindow) const = 0;
+ virtual tools::Rectangle GetWindowExtentsAbsolute() const = 0;
+ virtual tools::Rectangle GetWindowExtentsRelative(const vcl::Window& rRelativeWindow) const = 0;
virtual void GrabFocus() = 0;
virtual css::uno::Reference< css::accessibility::XAccessible > GetAccessible() = 0;
virtual vcl::Window* GetAccessibleParentWindow() const = 0;
diff --git a/include/vcl/toolkit/svtabbx.hxx b/include/vcl/toolkit/svtabbx.hxx
index efed0e36df95..3039c1aebe8d 100644
--- a/include/vcl/toolkit/svtabbx.hxx
+++ b/include/vcl/toolkit/svtabbx.hxx
@@ -192,7 +192,8 @@ public:
virtual bool GetGlyphBoundRects( const Point& rOrigin, const OUString& rStr, int nIndex, int nLen, std::vector< tools::Rectangle >& rVector ) override;
// Window
- virtual tools::Rectangle GetWindowExtentsRelative(const vcl::Window *pRelativeWindow) const override;
+ virtual tools::Rectangle GetWindowExtentsAbsolute() const override;
+ virtual tools::Rectangle GetWindowExtentsRelative(const vcl::Window& rRelativeWindow) const override;
virtual void GrabFocus() override;
virtual css::uno::Reference< css::accessibility::XAccessible > GetAccessible() override;
/** Creates and returns the accessible object of the whole BrowseBox. */
diff --git a/include/vcl/window.hxx b/include/vcl/window.hxx
index c6ba57ef7e35..4eb929804573 100644
--- a/include/vcl/window.hxx
+++ b/include/vcl/window.hxx
@@ -695,8 +695,6 @@ private:
SAL_DLLPRIVATE vcl::Window* ImplGetTopmostFrameWindow();
- SAL_DLLPRIVATE tools::Rectangle ImplGetWindowExtentsRelative(const vcl::Window *pRelativeWindow) const;
-
SAL_DLLPRIVATE bool ImplStopDnd();
SAL_DLLPRIVATE void ImplStartDnd();
@@ -947,8 +945,10 @@ public:
Point OutputToAbsoluteScreenPixel( const Point& rPos ) const;
Point AbsoluteScreenToOutputPixel( const Point& rPos ) const;
tools::Rectangle GetDesktopRectPixel() const;
- // window extents including border and decoration
- tools::Rectangle GetWindowExtentsRelative(const vcl::Window *pRelativeWindow) const;
+ // window extents including border and decoration, relative to passed in window
+ tools::Rectangle GetWindowExtentsRelative(const vcl::Window& rRelativeWindow) const;
+ // window extents including border and decoration, in absolute screen coordinates
+ tools::Rectangle GetWindowExtentsAbsolute() const;
bool IsScrollable() const;
virtual void Scroll( tools::Long nHorzScroll, tools::Long nVertScroll,